<?php // $Id: lib-db.inc.php,v 1.3 2001/10/26 20:37:05 ciaccia Exp $

/************************************************************************/
/* phpPgAds                                                             */
/* ========                                                             */
/*                                                                      */
/* Copyright (c) 2001 by the phpPgAds developers                        */
/* http://sourceforge.net/projects/phppgads                             */
/*                                                                      */
/* This program is free software. You can redistribute it and/or modify */
/* it under the terms of the GNU General Public License as published by */
/* the Free Software Foundation; either version 2 of the License.       */
/************************************************************************/



// PostgreSQL DB Resource and Result Counters
$phpAds_db_link = '';
$phpPgAds_db_cache = array();


/*********************************************************/
/* Open a connection to the database                     */
/*********************************************************/

function phpAds_dbConnect()
{
	global $phpAds_persistent_connections;
	global $phpAds_hostname, $phpAds_pgsqluser, $phpAds_pgsqlpassword, $phpAds_db;
	global $phpAds_db_link;
	global $phpPgAds_timezone;

	$conn_str = (empty($phpAds_hostname) ? "" : "host=$phpAds_hostname ")."dbname=$phpAds_db user=$phpAds_pgsqluser".
		(empty($phpAds_pgsqlpassword) ? "" : " password=$phpAds_pgsqlpassword");

	if ($GLOBALS["phpAds_persistent_connections"])
		$phpAds_db_link = @pg_pconnect($conn_str);
	else
		$phpAds_db_link = @pg_connect($conn_str);

	if (!empty($phpPgAds_timezone))
		pg_Exec($phpAds_db_link, "SET TIMEZONE = '$phpPgAds_timezone'");

	return $phpAds_db_link;
	}



/*********************************************************/
/* Close the connection to the database			         */
/*********************************************************/

function phpAds_dbClose()
{
	global $phpAds_persistent_connections;
	global $phpAds_db_link;
	
	if (!$phpAds_persistent_connections)
		@pg_close ($phpAds_db_link);
}



/*********************************************************/
/* Execute a query                                       */
/*********************************************************/

function phpAds_dbQuery($query, $link = "")
	{
    global $phpAds_last_query;
	global $phpAds_db_link;
	
    $phpAds_last_query = $query;
	
    $res = @pg_exec($phpAds_db_link, $query);

	if ($res)
		$GLOBALS['phpPgAds_db_cache'][$res] = 0;

	return $res;
	}



/*********************************************************/
/* Get the number of rows returned                       */
/*********************************************************/

function phpAds_dbNumRows($res)
{
	return @pg_numrows($res);
}



/*********************************************************/
/* Get next row as an array with keys                    */
/*********************************************************/

function phpAds_dbFetchArray($res)
{
	if (isset($GLOBALS['phpPgAds_db_cache'][$res]))
		return @pg_fetch_array($res, $GLOBALS['phpPgAds_db_cache'][$res]++);

	return false;
}



/*********************************************************/
/* Get next row as an array                              */
/*********************************************************/

function phpAds_dbFetchRow($res)
{
	if (isset($GLOBALS['phpPgAds_db_cache'][$res]))
		return @pg_fetch_row($res, $GLOBALS['phpPgAds_db_cache'][$res]++);

	return false;
}



/*********************************************************/
/* Get a specific row and column                         */
/*********************************************************/

function phpAds_dbResult($res, $row, $column)
{
	return @pg_result($res, $row, $column);
}



/*********************************************************/
/* Free the result from memory                           */
/*********************************************************/

function phpAds_dbFreeResult($res)
{
	if (isset($GLOBALS['phpPgAds_db_cache'][$res]))
		unset($GLOBALS['phpPgAds_db_cache'][$res]);

	return @pg_freeresult($res);
}



/*********************************************************/
/* Return the number of affected rows                    */
/*********************************************************/

function phpAds_dbAffectedRows($res)
{
	return @pg_cmdtuples($res);
}



/*********************************************************/
/* Go to the specified row                               */
/*********************************************************/

function phpAds_dbSeekRow($res, $row)
{
	if (isset($GLOBALS['phpPgAds_db_cache'][$res]))
	{
		$GLOBALS['phpPgAds_db_cache'][$res] = $row;
		return true;
	}

	return false;
}



/*********************************************************/
/* Get the ID of the last inserted row                   */
/*********************************************************/

function phpAds_dbInsertID($seq_name)
{
	return phpAds_dbResult(phpAds_dbQuery("SELECT last_value FROM $seq_name"), 0, 0);
}



/*********************************************************/
/* Get the error message if something went wrong         */
/*********************************************************/

function phpAds_dbError ()
{
	global $phpAds_db_link;
	
	return @pg_errormessage($phpAds_db_link);
}



/*********************************************************/
/* Return a large object - phpPgAds only                 */
/*********************************************************/

function phpPgAds_lo_read($oid)
{
	global $phpAds_db_link;
	
	phpAds_dbQuery("BEGIN");
	$lo = @pg_loopen($phpAds_db_link, $oid, "r") or die("Error");
	$res = '';
	while ($buf = @pg_loread($lo, 65536))
		$res .= $buf;
	@pg_loclose($lo);
	phpAds_dbQuery("END");
		
	return $res;
}



/*********************************************************/
/* Return a large object banner - phpPgAds only          */
/*********************************************************/

function phpPgAds_lo_banner($banner)
{
	if (ereg("^oid:([0-9]+)$", $banner, $match))
		$banner = phppgads_lo_read($match[1]);
		
	return $banner;
}



/*********************************************************/
/* Create a large object - phpPgAds only                 */
/*********************************************************/

function phpPgAds_lo_create($contents, $transaction = true)
{
	global $phpAds_db_link;
	
	if ($transaction)
		phpAds_dbQuery("BEGIN");
		
	if ($oid = @pg_locreate($phpAds_db_link))
	{
		if ($fd = @pg_loopen($phpAds_db_link, $oid, "wb"))
		{
			if (pg_lowrite($fd, $contents))
			{
				@pg_loclose($fd);
				
				if ($transaction)
					phpAds_dbQuery("COMMIT");
					
				return $oid;
			}
		}
	}
	
	if ($transaction)
		phpAds_dbQuery("ROLLBACK");

	return false;
}

?>
